if (!require("pacman")) install.packages("pacman")
pacman::p_load(dplyr,ggplot2,tidyr,Cairo,showtext,ggrepel,gplots,mixOmics,ggpubr)
showtext_auto(enable=T)
font_add("TNM","timesbd.ttf")
size = 30
themes <- #theme_bw()+
  theme(#panel.background = element_rect(color = 'black'),
    title = element_text(size=size,family="TNM",color="black"),
    axis.text.x = element_text(size=25,face="bold",family="TNM",color="black"),
    axis.text.y = element_text(size=25,face="bold",family="TNM",color="black"),
    axis.title.x= element_text(size=size,face="bold",family="TNM",hjust=0.5,color="black"),
    axis.title.y= element_text(size=size,face="bold",family="TNM",hjust=0.5,color="black"),
    legend.text=element_text(color="black",size=size, face="bold",family = "TNM"),
    legend.title = element_text(color="black", size=size, face="bold",family = "TNM"),
    plot.title = element_text(hjust = 0.5),
    strip.text.x = element_text(size=size, angle=0, face="bold"),
    strip.text.y = element_text(size=size, face="bold"),
    strip.background = element_rect(colour="black", fill="white"))

setwd("E:")
data<-read.csv("1310.CSV",row.names=1,encoding = "UTF-8")
###===========volcano plot
treat<-sapply(strsplit(colnames(data),"_"),'[',1)
gps<-unique(treat)
ND<-which(treat==gps[1])# ND
HFD<-which(treat==gps[2])# HFD
GP<-which(treat==gps[3])# GP
cetd<-data
head(cetd)
vd <- data.frame(rownames(cetd))[-1]
rownames(vd) <- rownames(cetd)
for (i in 1:nrow(cetd)) {
  vd$FChvn[i]<-mean(as.numeric(cetd[i,HFD]),na.rm=TRUE)/mean(as.numeric(cetd[i,ND]),na.rm=TRUE)
  vd$FCgvh[i]<-mean(as.numeric(cetd[i,GP]),na.rm=TRUE)/mean(as.numeric(cetd[i,HFD]),na.rm=TRUE)
}
vd$Fhvn<-apply(cetd,1,function(x) var.test(x[HFD],x[ND])$p.value)
vd$Fgvh<-apply(cetd,1,function(x) var.test(x[GP],x[HFD])$p.value)
VFhvn<-which(vd$Fhvn>0.05)
VFgvh<-which(vd$Fgvh>0.05)

#Ttest
vd$Phvn<- 1
vd$Phvn[ VFhvn]=apply(cetd[ VFhvn,],1,function(x) t.test(x[HFD],x[ND],paired = F,var.equal=TRUE)$p.value)
vd$Phvn[-VFhvn]=apply(cetd[-VFhvn,],1,function(x) t.test(x[HFD],x[ND],paired = F,var.equal=FALSE)$p.value)
vd$Pgvh<- 1
vd$Pgvh[ VFgvh]=apply(cetd[ VFgvh,],1,function(x) t.test(x[GP],x[HFD],paired = F,var.equal=TRUE)$p.value)
vd$Pgvh[-VFgvh]=apply(cetd[-VFgvh,],1,function(x) t.test(x[GP],x[HFD],paired = F,var.equal=FALSE)$p.value)

vd$shvn<-"Not"
vd$shvn[vd$Phvn<0.05 & vd$FChvn > 1.5]<-"Up"
vd$shvn[vd$Phvn<0.05 & vd$FChvn < 1/1.5]<-"Down"
vd$sgvh<-"Not"
vd$sgvh[vd$Pgvh<0.05 & vd$FCgvh > 1.5]<-"Up"
vd$sgvh[vd$Pgvh<0.05 & vd$FCgvh < 1/1.5]<-"Down"

dir.create('volcano')
head(vd)
ggplot(data=vd,aes(log(FChvn,2),-log(Phvn,10)))+
  geom_point(aes(color=shvn),size=5)+
  labs(title="HFD vs ND",col = '')+
  labs(x=expression(bold(log[2](FoldChange))), 
       y=expression(bold(-log[10](P~value))),
       color = '')+
  scale_color_manual(values = c('blue','grey50','red')) +
  geom_hline(yintercept=-log(0.05,10),linetype="dashed" )+
  geom_vline(xintercept=0,linetype="dashed")+
  scale_x_continuous(limits = c(-6,6),breaks=c(seq(-6,6,by = 2)))+
  themes
ggsave('volcano/fig_1_HFD_vs_ND_volcano.pdf',width = 12,height = 10)

ggplot(data=vd,aes(log(FCgvh,2),-log(Pgvh,10)))+
  geom_point(aes(color=sgvh),size=3)+
  labs(title="GP vs HFD",hjust = .8,col = '')+
  labs(x=expression(bold(log[2](FoldChange))), 
       y=expression(bold(-log[10](P~value))),
       color = '')+
  scale_color_manual(values = c('blue','grey50','red')) +
  geom_hline(yintercept=-log(0.05,10),linetype="dashed" )+
  geom_vline(xintercept=0,linetype="dashed")+
  scale_x_continuous(limits = c(-6,6),breaks=c(seq(-6,6,by = 2)))+
  themes
ggsave('volcano/fig_2_GP_vs_HFD_volc no.pdf',width = 12,height = 10)

table(vd$shvn)
table(vd$sgvh)
write.csv(vd,'DEGs.csv')

dir.create('veen')
library("VennDiagram")
HFD_vs_ND_Up <- rownames(vd)[(which(vd$shvn == 'Up'))]
HFD_vs_ND_Down <- rownames(vd)[(which(vd$shvn == 'Down'))]
GP_vs_HFD_Up <- rownames(vd)[which(vd$sgvh ==  'Up')]
GP_vs_HFD_Down <- rownames(vd)[which(vd$sgvh == 'Down')]
venn_list <-list(HFD_vs_ND_Up=HFD_vs_ND_Up,
                 HFD_vs_ND_Down=HFD_vs_ND_Down,
                 GP_vs_HFD_Up=GP_vs_HFD_Up,
                 GP_vs_HFD_Down=GP_vs_HFD_Down)
venn.plot <- venn.diagram(venn_list,
                          filename = "veen/fig_3_HFD_ND_GP.venn.png",
                          lty = 1,
                          lwd = 1,
                          col = "transparent",
                          fill = c("cornflowerblue", "green", "yellow","darkorchid1"),
                          alpha = 0.50,
                          cat.col = "black",
                          cat.cex = 1.0,
                          cat.fontface = "bold",
                          margin = 0.07,
                          cex = 1.2)
inter <- get.venn.partitions(venn_list)
for (i in 1:nrow(inter)) inter[i,'values'] <- paste(inter[[i,'..values..']], collapse = ', ')
write.csv(inter[-c(5, 6)], 'veen/table_1_venn4_inter.csv', row.names = FALSE, quote = FALSE)






